from __future__ import division, print_function

import pygame

import es
import events
import render
import scribe
import settings
import tools


def background(image):
    img = tools.load_image(image)
    rect = pygame.rect.Rect(img.get_rect())
    rect.center = (settings.WINDOW_WIDTH//2, settings.WINDOW_HEIGHT//2)
    draw = render.Drawable(img, layer="bg")
    return es.Entity(rect=rect, image=draw)

def card(cardtype, position):
    image = render.Drawable(cardtype.image)
    rect = pygame.rect.Rect(cardtype.image.get_rect())
    rect.center = position
    return es.Entity(rect=rect, image=image, card=cardtype)

def label(position, text, size=16, fontname=None, colour=(255,255,255)):
    image = scribe.label(text,size,fontname,colour)
    rect = pygame.rect.Rect(image.get_rect())
    rect.center = position
    return es.Entity(rect=rect, image=render.Drawable(image))

def help_splash(image):
    position = (settings.WINDOW_WIDTH//2, 220)
    entity = sticker(image, position)
    entity["dismissable"] = 0.5
    entity["death ticket"] = events.ticket()
    return entity

def banner(text, depth, time, size=48, fontname=None, colour=(255,255,255)):
    x = settings.WINDOW_WIDTH/2
    y = depth
    entity = label((x,y), text, size, fontname, colour)
    entity["lifespan"] = time
    return entity

def sticker(image, position, layer="fg"):
    image = tools.load_image(image)
    rect = pygame.rect.Rect(image.get_rect())
    rect.center = position
    return es.Entity(rect=rect, image=render.Drawable(image, layer))

def status_panel(player):
    height = 60
    nameplate = label((0, height), player.name, size=48)
    statusplate = label((0, height+30), player.status, size=32)
    scoreplate = label((0, height+60), "Score: {}".format(player.points),
                       size=32, colour=(100,255,100))    
    frames = [nameplate, statusplate, scoreplate]
    if player.chance:
        chanceplate = label((0, height-40), "Chance!", size=48, colour=(255,220,80))
        frames.append(chanceplate)
    x = 10 if player.side == "left" else settings.WINDOW_WIDTH-10
    for frame in frames:
        setattr(frame["rect"], player.side, x)
    return frames

def set_timer(time, world):
    ticket = events.ticket()
    entity = es.Entity()
    entity["lifespan"] = time
    entity["death ticket"] = ticket
    world.add_entity(entity)
    return ticket
