from __future__ import division, print_function

import pygame

import data
import scribe


IMAGES = {}
SOUNDS = {}

CURRENT_MUSIC = None

VOLUMES = {
    "win.ogg": 0.20,
    "win2.ogg": 0.20,
    "place.ogg": 0.35,
    "lose.ogg": 0.25,
    }

def load_image(filename):
    img = IMAGES.get(filename)
    if not img:
        try:
            path = data.filepath(filename)
            img = pygame.image.load(path).convert_alpha()
        except:
            img = get_placeholder(filename)
        IMAGES[filename] = img
    return img

def play_sound(filename):
    snd = SOUNDS.get(filename)
    if not snd:
        snd = pygame.mixer.Sound(data.filepath(filename))
        if filename in VOLUMES:
            snd.set_volume(VOLUMES[filename])
        SOUNDS[filename] = snd
    snd.play()

def get_placeholder(filename):
    surf = pygame.Surface((64,64))
    surf.fill((0,0,0))
    pygame.draw.rect(surf, (255,255,255), (0,0,64,64), 1)
    text = scribe.label(filename)
    surf.blit(text, (4,4))
    return surf
    
def play_music(filename):
    if CURRENT_MUSIC != filename:
        path = data.filepath(filename)
        pygame.mixer.music.load(path)
    pygame.mixer.music.play(-1)
    
def stop_music():
    pygame.mixer.music.stop()

def fade_music(time):
    pygame.mixer.music.fadeout(0.8)
